@@ -10,9 +10,9 @@ ACCESS_DENIED = "ACCESS_DENIED"
 class GraphQLPermissionDenied(BaseGraphQLError):
     """Permission denied error."""
 
-    _default_message: str = _(
+    default_message: str = _(
         "You do not have permission to perform this action",
     )
-    _default_extensions: Optional[Dict[str, str]] = {
+    default_extensions: Optional[Dict[str, str]] = {
         "code": ACCESS_DENIED,
     }
